@@ -26,9 +26,10 @@ import logging
 import logging.config
 import os
 
-from .builder import ImageBuilder
 import freedommaker
 
+from .builder import ImageBuilder
+
 IMAGE_SIZE = '3800M'
 BUILD_MIRROR = 'http://deb.debian.org/debian'
 MIRROR = 'http://deb.debian.org/debian'
@@ -66,19 +67,16 @@ class Application(object):
 
             cls = ImageBuilder.get_builder_class(target)
             if not cls:
-                logger.warn('Unknown target - %s', target)
+                logger.warning('Unknown target - %s', target)
                 continue
 
             builder = cls(self.arguments)
-            self.setup_logging(builder.log_file)
             try:
                 builder.build()
                 logger.info('Target complete - %s', target)
             except:
                 logger.error('Target failed - %s', target)
                 raise
-            finally:
-                builder.cleanup()
 
     def parse_arguments(self):
         """Parse command line arguments."""
@@ -88,9 +86,6 @@ class Application(object):
             description='FreedomMaker - Script to build FreedomBox images',
             formatter_class=argparse.ArgumentDefaultsHelpFormatter
         )
-        parser.add_argument(
-            '--vmdebootstrap', default='vmdebootstrap',
-            help='Path to vmdebootstrap executable')
         parser.add_argument(
             '--build-stamp', default=build_stamp,
             help='Build stamp to use on image file names')
@@ -137,12 +132,14 @@ class Application(object):
             '--build-in-ram', action='store_true',
             help='Build the image in RAM so that it is faster, requires '
             'free RAM about the size of disk image')
-        parser.add_argument(
-            'targets', nargs='+', help='Image targets to build')
+        parser.add_argument('--skip-compression', action='store_true',
+                            help='Do not compress the generated image')
+        parser.add_argument('targets', nargs='+',
+                            help='Image targets to build')
 
         self.arguments = parser.parse_args()
 
-    def setup_logging(self, log_file=None):
+    def setup_logging(self):
         """Setup logging."""
         config = {
             'version': 1,
